# tau-lidar-common

[![Documentation Status](https://readthedocs.org/projects/taulidarcommon/badge/?version=latest)](https://taulidarcommon.readthedocs.io/en/latest/?badge=latest)

Common library for Onion Tau LiDAR Camera

![Onion Tau Lidar Camera](https://github.com/OnionIoT/tau-lidar-common/blob/master/docs/img/onion-tau-lidar-camera-00.png)

## Main Features

* Methods and objects to compose, colour, and store 3D frames based on collected data

## Installation & Supported Versions

Install using pip on the command line:

```
python -m pip install TauLidarCommon
```

Supports Python 3.6.1+

## API Reference & Documentation on [ReadTheDocs](https://taulidarcommon.readthedocs.io/)

Documentation & API reference can be found online: https://taulidarcommon.readthedocs.io/

## Contributing to Development

See the [development document](DEVELOPMENT.md) for instructions on local development.

More info on contributing coming soon!
